==> paraview-v2.4.4.zip: paraview-v2.4.4/GUI/Widgets/Resources/ConvertResources.sh <==
KWConvertImageToHeader --zlib --base64 \
    vtkKWWindowLayoutResources.h \
    KWWindowLayout1x1.png \
    KWWindowLayout1x2.png \
    KWWindowLayout2x1.png \
    KWWindowLayout2x2.png \
    KWWindowLayout2x3.png \
    KWWindowLayout3x2.png 

KWConvertImageToHeader --zlib --base64 \
    vtkKWIconResources.h \
    bounding_box.png \
    color_bar_annotation.png \
    connection.png \
    corner_annotation.png \
    document.png \
    empty_16x16.png \
    empty_1x1.png \
    error.png \
    error_mini.png \
    error_red_mini.png \
    expand.png \
    file_open.png \
    floppy.png \
    folder.png \
    folder_open.png \
    grid_linear.png \
    grid_log.png \
    header_annotation.png \
    helpbubble.png \
    info_mini.png \
    lock.png \
    mag_glass.png \
    minus.png \
    move.png \
    move_h.png \
    move_v.png \
    orientation_cube_annotation.png \
    pan_hand.png \
    plus.png \
    point_finger.png \
    preset_add.png \
    preset_apply.png \
    preset_delete.png \
    preset_update.png \
    question.png \
    reload.png \
    rotate.png \
    scale_bar_annotation.png \
    shrink.png \
    side_annotation.png \
    stopwatch.png \
    transport_beginning.png \
    transport_end.png \
    transport_fast_forward.png \
    transport_fast_forward_to_key.png \
    transport_loop.png \
    transport_pause.png \
    transport_play.png \
    transport_play_to_key.png \
    transport_rewind.png \
    transport_rewind_to_key.png \
    transport_stop.png \
    trashcan.png \
    tree_close.png \
    tree_open.png \
    warning.png \
    warning_mini.png \
    window_level.png

==> paraview-v2.6.2.zip: paraview-v2.6.2/GUI/Widgets/Resources/ConvertResources.sh <==
KWConvertImageToHeader --zlib --base64 \
    vtkKWWindowLayoutResources.h \
    KWWindowLayout1x1.png \
    KWWindowLayout1x2.png \
    KWWindowLayout2x1.png \
    KWWindowLayout2x2.png \
    KWWindowLayout2x3.png \
    KWWindowLayout3x2.png 

KWConvertImageToHeader --zlib --base64 \
    vtkKWIconResources.h \
    angle_tool.png \
    bidimensional_tool.png \
    bounding_box.png \
    bug_mini.png \
    camera.png \
    calculator.png \
    color_bar_annotation.png \
    color_squares.png \
    connection.png \
    contour_tool.png \
    corner_annotation.png \
    crop_tool.png \
    distance_tool.png \
    document.png \
    empty_16x16.png \
    empty_1x1.png \
    error.png \
    error_mini.png \
    error_red_mini.png \
    expand.png \
    expand_mini.png \
    eye.png \
    file_open.png \
    floppy.png \
    folder.png \
    folder_open.png \
    grid_linear.png \
    grid_log.png \
    header_annotation.png \
    helpbubble.png \
    info_mini.png \
    lock.png \
    mag_glass.png \
    minus.png \
    move.png \
    move_h.png \
    move_v.png \
    orientation_cube_annotation.png \
    pan_hand.png \
    plus.png \
    point_finger.png \
    preset_add.png \
    preset_apply.png \
    preset_delete.png \
    preset_email.png \
    preset_locate.png \
    preset_update.png \
    question.png \
    reload.png \
    rotate.png \
    scale_bar_annotation.png \
    shrink.png \
    side_annotation.png \
    spin_down.png \
    spin_left.png \
    spin_right.png \
    spin_up.png \
    stopwatch.png \
    transport_beginning.png \
    transport_end.png \
    transport_fast_forward.png \
    transport_fast_forward_to_key.png \
    transport_loop.png \
    transport_pause.png \
    transport_play.png \
    transport_play_to_key.png \
    transport_rewind.png \
    transport_rewind_to_key.png \
    transport_stop.png \
    trashcan.png \
    tree_close.png \
    tree_open.png \
    warning.png \
    warning_mini.png \
    window_level.png \
    contour_segment.png \
    browserup.png \
    browserback.png \
    browserforward.png \
    filedelete.png \
    foldernew.png \
    cdrom.png \
    harddisk.png \
    floppydrive.png \
    netdrive.png \
    favorites.png \
    folder32.png \
    folderxp.png
